==> apache-ignite-slim-2.12.0-bin.zip: apache-ignite-slim-2.12.0-bin/platforms/cpp/docs/search/all_0.js <==
var searchData=
[
  ['active_0',['ACTIVE',['../structignite_1_1transactions_1_1TransactionState.html#a173faba612c6a4e91c0726140d8d43f3acefa9fd283ef4376d8053f4b7d68408b',1,'ignite::transactions::TransactionState']]],
  ['addargument_1',['AddArgument',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#ac12b5dbd6439fe7f50d6eb86c06a06ea',1,'ignite::cache::query::SqlQuery::AddArgument()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a65b0e8a6b2338db00571ba7d5b2bc798',1,'ignite::cache::query::SqlFieldsQuery::AddArgument()'],['../classignite_1_1thin_1_1cache_1_1query_1_1SqlFieldsQuery.html#ae7c1df1fb01b6b91515ca6ba95c8c66b',1,'ignite::thin::cache::query::SqlFieldsQuery::AddArgument()']]],
  ['addint8arrayargument_2',['AddInt8ArrayArgument',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ab0639495add2e0920b005bb7c7049b12',1,'ignite::cache::query::SqlFieldsQuery::AddInt8ArrayArgument()'],['../classignite_1_1thin_1_1cache_1_1query_1_1SqlFieldsQuery.html#a93fef79a0487c3a6b434e419612e29a8',1,'ignite::thin::cache::query::SqlFieldsQuery::AddInt8ArrayArgument()']]],
  ['affinitycall_3',['AffinityCall',['../classignite_1_1compute_1_1Compute.html#a530a3cce23a9d2707c08d539f26c5006',1,'ignite::compute::Compute']]],
  ['affinitycallasync_4',['AffinityCallAsync',['../classignite_1_1compute_1_1Compute.html#a8bc07e207eac96a2f237ba88aef38aaf',1,'ignite::compute::Compute']]],
  ['affinityrun_5',['AffinityRun',['../classignite_1_1compute_1_1Compute.html#a0a6dc52f89ac7994ee603276997a4f71',1,'ignite::compute::Compute']]],
  ['affinityrunasync_6',['AffinityRunAsync',['../classignite_1_1compute_1_1Compute.html#ae03bdc90e6e895dd59186ad478a9ffff',1,'ignite::compute::Compute']]],
  ['all_7',['ALL',['../structignite_1_1cache_1_1CachePeekMode.html#acd2d0e89b2c2c9d391060a89585bc2b2ac963dd400d80659ced9e17f5474663c6',1,'ignite::cache::CachePeekMode::ALL()'],['../structignite_1_1thin_1_1cache_1_1CachePeekMode.html#a272b97468acc45f2b16d89c65e9891c6a8c93b9244a045bfadca274d54ed70723',1,'ignite::thin::cache::CachePeekMode::ALL()']]],
  ['array_5flist_8',['ARRAY_LIST',['../structignite_1_1binary_1_1CollectionType.html#a03610e138c65428dc81c08f62b7729bbacbc1082191c5452d77c8ffcfc012b8be',1,'ignite::binary::CollectionType']]],
  ['asclustergroup_9',['AsClusterGroup',['../classignite_1_1cluster_1_1IgniteCluster.html#a557842993b06ffbd08821c4aa18cbf44',1,'ignite::cluster::IgniteCluster']]],
  ['attachhelper_10',['AttachHelper',['../classignite_1_1jni_1_1AttachHelper.html',1,'ignite::jni']]],
  ['apache_20ignite_20c_2b_2b_11',['Apache Ignite C++',['../index.html',1,'']]],
  ['apache_20ignite_20thin_20c_2b_2b_20client_12',['Apache Ignite Thin C++ client',['../md__data_tcAgent_work_1f1fbf2404a79d40_ignite_modules_platforms_cpp_thin-client_README.html',1,'']]]
];

==> apache-ignite-slim-2.14.0-bin.zip: apache-ignite-slim-2.14.0-bin/platforms/cpp/docs/search/all_0.js <==
var searchData=
[
  ['active_0',['ACTIVE',['../structignite_1_1transactions_1_1TransactionState.html#a173faba612c6a4e91c0726140d8d43f3acefa9fd283ef4376d8053f4b7d68408b',1,'ignite::transactions::TransactionState']]],
  ['addargument_1',['AddArgument',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#ac12b5dbd6439fe7f50d6eb86c06a06ea',1,'ignite::cache::query::SqlQuery::AddArgument()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a65b0e8a6b2338db00571ba7d5b2bc798',1,'ignite::cache::query::SqlFieldsQuery::AddArgument()'],['../classignite_1_1thin_1_1cache_1_1query_1_1SqlFieldsQuery.html#ae7c1df1fb01b6b91515ca6ba95c8c66b',1,'ignite::thin::cache::query::SqlFieldsQuery::AddArgument()']]],
  ['addint8arrayargument_2',['AddInt8ArrayArgument',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ab0639495add2e0920b005bb7c7049b12',1,'ignite::cache::query::SqlFieldsQuery::AddInt8ArrayArgument()'],['../classignite_1_1thin_1_1cache_1_1query_1_1SqlFieldsQuery.html#a93fef79a0487c3a6b434e419612e29a8',1,'ignite::thin::cache::query::SqlFieldsQuery::AddInt8ArrayArgument()']]],
  ['affinitycall_3',['AffinityCall',['../classignite_1_1compute_1_1Compute.html#a530a3cce23a9d2707c08d539f26c5006',1,'ignite::compute::Compute']]],
  ['affinitycallasync_4',['AffinityCallAsync',['../classignite_1_1compute_1_1Compute.html#a8bc07e207eac96a2f237ba88aef38aaf',1,'ignite::compute::Compute']]],
  ['affinityrun_5',['AffinityRun',['../classignite_1_1compute_1_1Compute.html#a0a6dc52f89ac7994ee603276997a4f71',1,'ignite::compute::Compute']]],
  ['affinityrunasync_6',['AffinityRunAsync',['../classignite_1_1compute_1_1Compute.html#ae03bdc90e6e895dd59186ad478a9ffff',1,'ignite::compute::Compute']]],
  ['all_7',['ALL',['../structignite_1_1cache_1_1CachePeekMode.html#acd2d0e89b2c2c9d391060a89585bc2b2ac963dd400d80659ced9e17f5474663c6',1,'ignite::cache::CachePeekMode::ALL()'],['../structignite_1_1thin_1_1cache_1_1CachePeekMode.html#a272b97468acc45f2b16d89c65e9891c6a8c93b9244a045bfadca274d54ed70723',1,'ignite::thin::cache::CachePeekMode::ALL()']]],
  ['array_5flist_8',['ARRAY_LIST',['../structignite_1_1binary_1_1CollectionType.html#a03610e138c65428dc81c08f62b7729bbacbc1082191c5452d77c8ffcfc012b8be',1,'ignite::binary::CollectionType']]],
  ['asclustergroup_9',['AsClusterGroup',['../classignite_1_1cluster_1_1IgniteCluster.html#a557842993b06ffbd08821c4aa18cbf44',1,'ignite::cluster::IgniteCluster']]],
  ['attachhelper_10',['AttachHelper',['../classignite_1_1jni_1_1AttachHelper.html',1,'ignite::jni']]],
  ['apache_20ignite_20c_2b_2b_11',['Apache Ignite C++',['../index.html',1,'']]],
  ['apache_20ignite_20thin_20c_2b_2b_20client_12',['Apache Ignite Thin C++ client',['../md__opt_buildagent_work_d03a92c4201fc315_ignite_modules_platforms_cpp_thin-client_README.html',1,'']]]
];
